summaryrefslogtreecommitdiffstats
path: root/src/svnqt
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commitc6b29717327388357badda064ef1ced71932406e (patch)
tree5d0dadae0d00c60e0773be4e8ee5a60a47615342 /src/svnqt
parent93f9fda465964160b66d9252d2cf9b4c284eab50 (diff)
downloadtdesvn-c6b29717327388357badda064ef1ced71932406e.tar.gz
tdesvn-c6b29717327388357badda064ef1ced71932406e.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kdesvn@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/svnqt')
-rw-r--r--src/svnqt/cache/ReposLog.cpp2
-rw-r--r--src/svnqt/cache/sqlite3/qsql_sqlite3.cpp8
-rw-r--r--src/svnqt/cache/sqlite3/qsql_sqlite3.h4
-rw-r--r--src/svnqt/client.hpp4
-rw-r--r--src/svnqt/path.hpp2
-rw-r--r--src/svnqt/pool.cpp10
-rw-r--r--src/svnqt/pool.hpp8
7 files changed, 19 insertions, 19 deletions
diff --git a/src/svnqt/cache/ReposLog.cpp b/src/svnqt/cache/ReposLog.cpp
index 54c4622..d63d1d3 100644
--- a/src/svnqt/cache/ReposLog.cpp
+++ b/src/svnqt/cache/ReposLog.cpp
@@ -410,7 +410,7 @@ bool svn::cache::ReposLog::log(const svn::Path&what,const svn::Revision&_start,
*/
bool svn::cache::ReposLog::itemExists(const svn::Revision&peg,const svn::Path&path)
{
- /// @todo this moment I have no idea how to check real with all moves and deletes of tqparent folders without a hell of sql statements so we make it quite simple: it exists if we found it.
+ /// @todo this moment I have no idea how to check real with all moves and deletes of parent folders without a hell of sql statements so we make it quite simple: it exists if we found it.
#if 0
diff --git a/src/svnqt/cache/sqlite3/qsql_sqlite3.cpp b/src/svnqt/cache/sqlite3/qsql_sqlite3.cpp
index 6a8bea2..408cb32 100644
--- a/src/svnqt/cache/sqlite3/qsql_sqlite3.cpp
+++ b/src/svnqt/cache/sqlite3/qsql_sqlite3.cpp
@@ -250,14 +250,14 @@ int TQSQLite3Result::numRowsAffected()
/////////////////////////////////////////////////////////
-TQSQLite3Driver::TQSQLite3Driver(TQObject * tqparent, const char *name)
- : TQSqlDriver(tqparent, name)
+TQSQLite3Driver::TQSQLite3Driver(TQObject * parent, const char *name)
+ : TQSqlDriver(parent, name)
{
d = new TQSQLite3DriverPrivate();
}
-TQSQLite3Driver::TQSQLite3Driver(sqlite3 *connection, TQObject *tqparent, const char *name)
- : TQSqlDriver(tqparent, name)
+TQSQLite3Driver::TQSQLite3Driver(sqlite3 *connection, TQObject *parent, const char *name)
+ : TQSqlDriver(parent, name)
{
d = new TQSQLite3DriverPrivate();
d->access = connection;
diff --git a/src/svnqt/cache/sqlite3/qsql_sqlite3.h b/src/svnqt/cache/sqlite3/qsql_sqlite3.h
index 85cc22f..7c474ca 100644
--- a/src/svnqt/cache/sqlite3/qsql_sqlite3.h
+++ b/src/svnqt/cache/sqlite3/qsql_sqlite3.h
@@ -54,8 +54,8 @@ class TQSQLite3Driver : public TQSqlDriver
{
friend class TQSQLite3Result;
public:
- TQSQLite3Driver(TQObject *tqparent = 0, const char *name = 0);
- TQSQLite3Driver(sqlite3 *connection, TQObject *tqparent = 0, const char *name = 0);
+ TQSQLite3Driver(TQObject *parent = 0, const char *name = 0);
+ TQSQLite3Driver(sqlite3 *connection, TQObject *parent = 0, const char *name = 0);
~TQSQLite3Driver();
bool hasFeature(DriverFeature f) const;
bool open(const TQString & db,
diff --git a/src/svnqt/client.hpp b/src/svnqt/client.hpp
index 95b7461..bffd219 100644
--- a/src/svnqt/client.hpp
+++ b/src/svnqt/client.hpp
@@ -373,7 +373,7 @@ namespace svn
*
* @param path
* @param message log message. if it is TQString() asks when working on repository
- * @param makeParent create tqparent folders if not existant (only when build with svn 1.5 or above)
+ * @param makeParent create parent folders if not existant (only when build with svn 1.5 or above)
* @exception ClientException
*/
virtual svn::Revision
@@ -390,7 +390,7 @@ namespace svn
*
* @param targets encoded pathes to create
* @param message log message. if it is TQString() asks when working on repository
- * @param makeParent create tqparent folders if not existant (only when build with svn 1.5 or above)
+ * @param makeParent create parent folders if not existant (only when build with svn 1.5 or above)
* @exception ClientException
*/
virtual svn::Revision
diff --git a/src/svnqt/path.hpp b/src/svnqt/path.hpp
index b9cc73f..9592aca 100644
--- a/src/svnqt/path.hpp
+++ b/src/svnqt/path.hpp
@@ -131,7 +131,7 @@ namespace svn
void
addComponent (const TQString & component);
- /** Reduce path to its tqparent folder.
+ /** Reduce path to its parent folder.
* If the path length is 1 (eg., only "/") it will cleared so
* path length will get zero.
* @sa svn_path_remove_component
diff --git a/src/svnqt/pool.cpp b/src/svnqt/pool.cpp
index 0f624b4..34ef947 100644
--- a/src/svnqt/pool.cpp
+++ b/src/svnqt/pool.cpp
@@ -37,17 +37,17 @@ namespace svn
bool Pool::s_initialized = false;
apr_pool_t *
- Pool::pool_create (apr_pool_t * tqparent)
+ Pool::pool_create (apr_pool_t * parent)
{
if (!s_initialized) {
apr_pool_initialize();
s_initialized=true;
}
- return svn_pool_create (tqparent);
+ return svn_pool_create (parent);
}
- Pool::Pool (apr_pool_t * tqparent)
- : m_tqparent (tqparent), m_pool (pool_create (tqparent))
+ Pool::Pool (apr_pool_t * parent)
+ : m_parent (parent), m_pool (pool_create (parent))
{
}
@@ -72,7 +72,7 @@ namespace svn
{
svn_pool_destroy (m_pool);
}
- m_pool = pool_create (m_tqparent);
+ m_pool = pool_create (m_parent);
}
//TODO
diff --git a/src/svnqt/pool.hpp b/src/svnqt/pool.hpp
index 46e0a8e..accdd75 100644
--- a/src/svnqt/pool.hpp
+++ b/src/svnqt/pool.hpp
@@ -46,9 +46,9 @@ namespace svn
/**
* creates a subpool new pool to an existing pool
*
* @param tqparent NULL -> global pool
*/
- Pool (apr_pool_t * tqparent = (apr_pool_t *)0);
+ Pool (apr_pool_t * parent = (apr_pool_t *)0);
virtual ~ Pool ();
@@ -71,7 +71,7 @@ namespace svn
*/
void renew ();
private:
- apr_pool_t * m_tqparent;
+ apr_pool_t * m_parent;
apr_pool_t * m_pool;
Pool& operator=(const Pool&);
@@ -79,7 +79,7 @@ namespace svn
Pool (const Pool &);
static bool s_initialized;
- static apr_pool_t * pool_create (apr_pool_t * tqparent);
+ static apr_pool_t * pool_create (apr_pool_t * parent);
};
}
@@ -46,9 +46,9 @@ namespace svn
* creates a subpool new pool to an existing pool
*
- * @param tqparent NULL -> global pool
+ * @param parent NULL -> global pool
*/